### Name: Interface between sp and bnd format
### Title: Convert sp and bnd format into each other
### Aliases: sp2bnd bnd2sp
### Keywords: spatial

### ** Examples

## bnd to sp:
germany <- read.bnd(system.file("examples/germany2001.bnd", package="BayesX"))
spGermany <- bnd2sp(germany)

## plot the result together with the neighborhood graph
library(sp)
plot(spGermany)
library(spdep)
nbGermany <- poly2nb(spGermany)
plot(nbGermany, coords=coordinates(spGermany), add=TRUE)

## example with one region inside another
spExample <- spGermany[c("7211", "7235"), ]
plot(spExample)
plot(poly2nb(spExample), coords=coordinates(spExample), add=TRUE)

## now back from sp to bnd:
bndGermany <- sp2bnd(spGermany)
drawmap(map=bndGermany)

## compare names and number of polygons
stopifnot(identical(names(bndGermany),
                    names(germany)),
          identical(length(bndGermany),
                    length(germany)))

## compare contains-relations
bndContainsData <- as.data.frame(attributes(bndGermany)[c("is.in", "contains")])
originalContainsData <- as.data.frame(attributes(germany)[c("is.in", "contains")])
stopifnot(all(bndContainsData[order(bndContainsData$is.in), ] ==
              originalContainsData[order(originalContainsData$is.in), ]))



